@@ -14,7 +14,7 @@ SCRIPT_DIR=$(cd "$(dirname "$0")"; pwd)
 
 DEFAULT_REGISTRY="quay.io"
 DEFAULT_ORGANIZATION="eclipse"
-DEFAULT_TAG="nightly"
+DEFAULT_TAG="next"
 
 REGISTRY=${REGISTRY:-${DEFAULT_REGISTRY}}
 ORGANIZATION=${ORGANIZATION:-${DEFAULT_ORGANIZATION}}
